@@ -1,6 +1,7 @@
 from .trainer import SegTrainer, ImSpecTrainer, BaseTrainer
 from .etrainer import BaseEnsembleTrainer, EnsembleTrainer
 from .vitrainer import viBaseTrainer
+from .gptrainer import dklGPTrainer
 
 __all__ = ["SegTrainer", "ImSpecTrainer", "BaseTrainer", "BaseEnsembleTrainer",
-           "EnsembleTrainer", "viBaseTrainer"]
\ No newline at end of file
+           "EnsembleTrainer", "viBaseTrainer", "dklGPTrainer"]
\ No newline at end of file
