@@ -151,7 +151,7 @@ def get_imgstack(imgdata: np.ndarray,
             img_cr = np.copy(
                 imgdata[cx-r//2:cx+r//2,
                         cy-r//2:cy+r//2])
-        if img_cr.shape[0:2] == (int(r), int(r)):
+        if img_cr.shape[0:2] == (int(r), int(r)) and not np.isnan(img_cr).any():
             img_cr_all.append(img_cr[None, ...])
             com.append(c[None, ...])
     if len(img_cr_all) == 0:
@@ -357,6 +357,8 @@ def extract_patches(images: np.ndarray, masks: np.ndarray,
     """
     if np.ndim(images) == 2:
         images = images[None, ...]
+    if np.ndim(masks) == 2:
+        masks = masks[None, ...]
     images_aug, masks_aug = [], []
     for im, ma in zip(images, masks):
         im_aug, ma_aug = extract_patches_(
